ServerConfig class

Constructors

ServerConfig({ServerType? type, String? hostname, int? port, SocketType? socketType, Authentication? authentication, UsernameType? usernameType})

Properties

authentication ↔ Authentication?
getter/setter pair
authenticationAlternative ↔ Authentication?
getter/setter pair
authenticationAlternativeName ↔ String?
getter/setter pair
authenticationName ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hostname ↔ String?
getter/setter pair
isSecureSocket → bool
no setter
port ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
socketType ↔ SocketType?
getter/setter pair
socketTypeName ↔ String
getter/setter pair
type ↔ ServerType?
getter/setter pair
typeName ↔ String
getter/setter pair
username ↔ String
getter/setter pair
usernameType ↔ UsernameType?
getter/setter pair

Methods

getUserName(String email) → String?
Retrieves the user name based on the specified email address. Returns null in case usernameType is UsernameType.realname or UsernameType.unknown.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(Map<String, dynamic> attributes) → void
Reads all field keys and values from the specified attributes map. This method is called after the de-serialization.
toString() → String
A string representation of this object.
override
write(Map<String, dynamic> attributes) → void
Sets all field keys and values in the specified attributes map. This method is called before the serialization.

Operators

operator ==(Object o) → bool
The equality operator.
override