ImapServerInfo class

Keeps information about the remote IMAP server

Persist this information to improve initialization times.

Constructors

ImapServerInfo(ConnectionInfo info)

Properties

capabilities ↔ List<Capability>?
getter/setter pair
capabilitiesText ↔ String?
getter/setter pair
enabledCapabilities → List<Capability>
final
hashCode → int
The hash code for this object.
no setterinherited
host → String
final
isSecure → bool
final
pathSeparator ↔ String?
getter/setter pair
port → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportedThreadingMethods → List<String>
Retrieves the supported threading methods, e.g. [], ['ORDEREDSUBJECT'] or ['ORDEREDSUBJECT', 'REFERENCES']
no setter
supportsIdle → bool
Does the server support IDLE?
no setter
supportsMove → bool
Does the server support MOVE?
no setter
supportsQresync → bool
Does the server support QRESYNC?
no setter
supportsThreading → bool
Does the server support THREAD?
no setter
supportsUidPlus → bool
Does the server support UID PLUS?
no setter
supportsUtf8 → bool
Does the server support UTF-8?
no setter

Methods

isEnabled(String capabilityName) → bool
Checks if the capability with the specified capabilityName has been enabled.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
supports(String capabilityName) → bool
Checks if the capability with the specified capabilityName is supported.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited