Mailbox class

Stores meta data about a folder aka Mailbox

Constructors

Mailbox()
Creates a new uninitialized Mailbox
Mailbox.setup(String name, String path, List<MailboxFlag> flags, {String? pathSeparator})
Creates a new mailbox with the specified name, path and flags.

Properties

encodedName → String
no setter
encodedPath → String
no setter
extendedData ↔ Map<String, List<String>>
Map of extended results
getter/setter pair
firstUnseenMessageSequenceId ↔ int?
getter/setter pair
flags ↔ List<MailboxFlag>
getter/setter pair
hasChildren ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasModSequence ↔ bool?
This is set to false in case the server supports CONDSTORE but no mod sequence for this mailbox
getter/setter pair
highestModSequence ↔ int?
The last modification sequence in case the server supports the CONDSTORE or QRESYNC capability. Useful for message synchronization.
getter/setter pair
isArchive → bool
no setter
isDrafts → bool
no setter
isInbox → bool
no setter
isJunk → bool
no setter
isMarked ↔ bool
getter/setter pair
isReadWrite ↔ bool
getter/setter pair
isSelected ↔ bool
getter/setter pair
isSent → bool
no setter
isSpecialUse → bool
no setter
isTrash → bool
no setter
isUnselectable ↔ bool
getter/setter pair
messageFlags ↔ List<String>?
getter/setter pair
messagesExists ↔ int
getter/setter pair
messagesRecent ↔ int?
getter/setter pair
messagesUnseen ↔ int?
The number of unseen messages - only reported through STATUS calls
getter/setter pair
name ↔ String
getter/setter pair
path ↔ String
getter/setter pair
pathSeparator ↔ String
getter/setter pair
permanentMessageFlags ↔ List<String>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uidNext ↔ int?
getter/setter pair
uidValidity ↔ int?
getter/setter pair

Methods

getParent(List<Mailbox> knownMailboxes, String separator, {bool create = true, bool createIntermediate = true}) → Mailbox?
Tries to determine the parent mailbox from the given knownMailboxes and separator.
hasFlag(MailboxFlag flag) → bool
Checks of the mailbox has the given flag
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setNameFromPath() → void
Sets the name from the original path
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(String path) → String
Helper method to encode the specified path in Modified UTF7 encoding.