QResyncParameters class

Classes for implementing QRESYNC https://tools.ietf.org/html/rfc7162 QRESYNC parameters when doing a SELECT or EXAMINE.

Constructors

QResyncParameters(int? lastKnownValidity, int? lastKnownModificationSequence)

Properties

hashCode → int
The hash code for this object.
no setterinherited
knownUids ↔ MessageSequence?
the optional set of known UIDs
getter/setter pair
lastKnownModificationSequence ↔ int?
the last known modification sequence of the mailbox / folder
getter/setter pair
lastKnownValidity ↔ int?
the last known UIDVALIDITY of the mailbox / folder
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(StringBuffer buffer) → void
Renders this parameter for an IMAP SELECT or EXAMINE command.
setKnownSequenceIdsWithTheirUids(MessageSequence knownSequenceIds, MessageSequence correspondingKnownUids) → void
Specifies the optional known message sequence IDs with knownSequenceIds along with their corresponding UIds correspondingKnownUids.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited