ResourceLimit class

QUOTA resource limit

Constructors

ResourceLimit(String name, int? currentUsage, int? usageLimit)

Properties

currentUsage → int?
Current resource usage in kibibytes.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The quota resource name.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usageLimit → int?
Usage limit of the resource as kibibytes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited