SortImapResult class

Result for SORT and UID SORT operations

Copy of SearchImapResult class because SEARCH and SORT are equivalents

Constructors

SortImapResult()

Properties

count ↔ int?
Matches count
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
highestModSequence ↔ int?
The highest modification sequence in the searched messages The modification sequeqnce can only be returned when the MODSEQ search criteria has been used and when the server supports the CONDSTORE capability.
getter/setter pair
isExtended ↔ bool?
Signals an extended sort result
getter/setter pair
isPartial → bool
no setter
matchingSequence ↔ MessageSequence?
A list of message IDs
getter/setter pair
max ↔ int?
Maximum found message ID or UID
getter/setter pair
min ↔ int?
Minimum found message ID or UID
getter/setter pair
partialRange ↔ String?
Range of the partial result returned
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag ↔ String?
Result tag
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited