MailServerConfig class

Configuration of an mail service

Constructors

MailServerConfig({ServerConfig? serverConfig, MailAuthentication? authentication, List<Capability>? serverCapabilities, String? pathSeparator})

Properties

attributes → Map<String, dynamic>
Holds all values that should be serialized. Can either be generated upon demand or used all the time. Example for using attributes as the data store:
no setterinherited
authentication ↔ MailAuthentication?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
objectCreators → Map<String, dynamic Function(Map<String, dynamic>?)>
Define functions that create new complex serializable or Map instances for nested objects. You can evaluate the provided map value to select a specific subclass, if needed.
no setterinherited
pathSeparator ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverCapabilities ↔ List<Capability>?
getter/setter pair
serverConfig ↔ ServerConfig?
getter/setter pair
transformers → Map<String, dynamic Function(dynamic)>
Define any transformations for values. You can transform an enumeration to an int and the other way round:
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
supports(String capabilityName) → bool
toString() → String
A string representation of this object.
override

Operators

operator ==(Object o) → bool
The equality operator.
override