MailConnectionReEstablishedEvent class

Notifies about a connection that has been re-established

Inheritance

Constructors

MailConnectionReEstablishedEvent(MailClient mailClient)

Properties

eventType → MailEventType
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
mailClient → MailClient
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited