MailEvent class

Base class for any event that can be fired by the MailClient at any time. Compare MailClient.eventBus

Implementers

Constructors

MailEvent(MailEventType eventType, MailClient mailClient)

Properties

eventType → MailEventType
final
hashCode → int
The hash code for this object.
no setterinherited
mailClient → MailClient
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited