MoveResult class

Constructors

MoveResult(bool isUndoable, MoveAction action, MessageSequence? originalSequence, Mailbox? originalMailbox, MessageSequence? targetSequence, Mailbox? targetMailbox)
Creates a new result for an move call

Properties

action → MoveAction
The internal action that was used to delete
final
hashCode → int
The hash code for this object.
no setterinherited
isUndoable ↔ bool
Is this delete result undoable?
getter/setter pair
originalMailbox → Mailbox?
The originating mailbox
final
originalSequence → MessageSequence?
The original message sequence used
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetMailbox → Mailbox?
The target mailbox
final
targetSequence → MessageSequence?
The resulting message sequence of the moved messages
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reverse() → MoveResult
Reverses the result so that the original sequence and mailbox becomes the target ones.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited