PagedMessageResult class

Base class for actions that result in a partial fetching of messages

Implementers

Constructors

PagedMessageResult(PagedMessageSequence pagedSequence, List<MimeMessage> messages, FetchPreference fetchPreference)
Creates a new paged result with the given messageSequence, messages and fetchPreference
PagedMessageResult.empty({FetchPreference fetchPreference = FetchPreference.envelope, int pageSize = 30})
Creates a new empty paged message result with the option fetchPreference (FetchPreference.envelope) and pageSize.

Properties

fetchPreference → FetchPreference
The original fetch preference
final
hashCode → int
The hash code for this object.
no setterinherited
hasMoreResults → bool
Checks if the messageSequence has a next page
no setter
isEmpty → bool
Checks if this result is empty
no setter
isNotEmpty → bool
Checks if this result is not empty
no setter
isUidBased → bool
Shortcut to find out if this search result is UID based
no setter
length → int
The number of all matching messages
no setter
messages → List<MimeMessage>
The fetched messages, initially this contains only the first page
final
pagedSequence → PagedMessageSequence
The message sequence containing all IDs or UIDs, may be null for empty searches
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addMessage(MimeMessage message) → void
Adds the specified message to this search result.
insertAll(List<MimeMessage> page) → void
Inserts the given page of messages to this result
isAvailable(int messageIndex) → bool
Checks if the message for the given messageIndex is already loaded.
isPageRequestedFor(int messageIndex) → bool
Checks if the page for the given message messageIndex is already requested.
messageIdAt(int messageIndex) → int
Retrieves the message ID at the specified messageIndex.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeMessage(MimeMessage message) → void
Adds the specified message to this search result.
removeMessageSequence(MessageSequence removeSequence) → List<MimeMessage>
Removes the specified removeSequence from this result and returns all messages that have been loaded.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int messageIndex) → MimeMessage
Retrieves the message for the given messageIndex.