ThreadDataResult class

Contains information about threads

Retrieve the thread sequence for a given message UID with threadDataResult[uid]. Example:

final sequence = threadDataResult[mimeMessage.uid];
if (sequence != null) {
  // the mimeMessage belongs to a thread
}

Constructors

ThreadDataResult(SequenceNode data, DateTime since)
Creates a new result with the given data and since.

Properties

data → SequenceNode
The source data
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
since → DateTime
The day since when threads were requested
final

Methods

hasThread(int id) → bool
Checks if the given id belongs to a thread.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setThreadSequence(MimeMessage mimeMessage) → void
Sets the MimeMessage.threadSequence for the specified mimeMessage
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int id) → MessageSequence?
Retrieves the thread sequence for the given message id.