ThreadResult class

Encapsulates a thread result

Constructors

ThreadResult(SequenceNode threadData, PagedMessageSequence threadSequence, ThreadPreference threadPreference, FetchPreference fetchPreference, DateTime since, List<MimeThread> threads)
Creates a new result with the given threadData, threadSequence, threadPreference, fetchPreference and the prefetched threads.

Properties

fetchPreference → FetchPreference
The fetch preference
final
hashCode → int
The hash code for this object.
no setterinherited
hasMoreResults → bool
Checks if the threadSequence has a next page
no setter
isUidBased → bool
Shortcut to find out if this thread result is UID based
no setter
length → int
Retrieves the total number of threads which can be higher than threads.length.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
since → DateTime
Since when the thread data is retrieved
final
threadData → SequenceNode
The source data
final
threadPreference → ThreadPreference
The thread preference
final
threads → List<MimeThread>
The threads that have been fetched so far
final
threadSequence → PagedMessageSequence
The paged message sequence
final

Methods

addAll(List<MimeMessage> unthreadedMessages) → void
Distributes the given unthreadedMessages to the threads managed by this result.
isPageRequestedFor(int threadIndex) → bool
Checks if the page for the given thread threadIndex is already requested in a ThreadPreference.latest based result.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int threadIndex) → MimeThread?
Eases access to the MimeThread at the specified threadIndex or null when it is not yet loaded.