AttachmentInfo class

Information about a file that is attached

Constructors

AttachmentInfo(File? file, MediaType mediaType, String? name, int? size, ContentDisposition? contentDisposition, Uint8List? data, PartBuilder part)

Properties

contentDisposition → ContentDisposition?
final
data → Uint8List?
final
file → File?
final
hashCode → int
The hash code for this object.
no setterinherited
mediaType → MediaType
final
name → String?
final
part → PartBuilder
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited