BinaryMimeData class

Represents binary mime data

Inheritance

Constructors

BinaryMimeData(Uint8List data, bool containsHeader)
Creates a new binary mime data with the specified data and the containsHeader info.

Properties

bodySize → int
no setterinherited
containsHeader → bool
Defines if this mime data includes header data
finalinherited
contentType → ContentTypeHeader?
no setterinherited
data → Uint8List
final
hashCode → int
The hash code for this object.
no setterinherited
hasParts → bool
Returns true when there are children
no setterinherited
headersList ↔ List<Header>?
All known headers of this mime data
getter/setter pairinherited
parts ↔ List<MimeData>?
The children of this mime data
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
no setterinherited

Methods

decodeBinary(String? contentTransferEncoding) → Uint8List
Decodes the data represented by the mime data
override
decodeMessageData() → MimeData?
Decodes message/rfc822 content
override
decodeText(ContentTypeHeader? contentTypeHeader, String? contentTransferEncoding) → String
Decodes the text represented by the mime data
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(ContentTypeHeader? contentTypeHeader) → void
Parses this data
inherited
render(StringBuffer buffer, {bool renderHeader = true}) → void
Renders this mime data.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited