BodyPart class

A BODY or BODYSTRUCTURE information element

Constructors

BodyPart()

Properties

allLeafParts → List<BodyPart>
Retrieves all leaf parts, ie all parts that have no children parts themselves.
no setter
bodyRaw ↔ String?
The raw text of this body part. This is set when fetching the message contents e.g. with BODY[].
getter/setter pair
cid ↔ String?
A string giving the content id as defined in MIME-IMB.
getter/setter pair
contentDisposition ↔ ContentDispositionHeader?
The content disposition information. This is constructed when querying BODYSTRUCTURE in a fetch.
getter/setter pair
contentType ↔ ContentTypeHeader?
The content type infomation.
getter/setter pair
description ↔ String?
A string giving the content description as defined in MIME-IMB.
getter/setter pair
encoding ↔ String?
A string giving the content transfer encoding as defined in MIME-IMB. Examples: base64, quoted-printable
getter/setter pair
envelope ↔ Envelope?
The envelope, only provided for message/rfc822 structures
getter/setter pair
fetchId → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
length → int
Retrieves the number of nested parts
no setter
numberOfLines ↔ int?
Some message types like MESSAGE/RFC822 or TEXT also provide the number of lines
getter/setter pair
parts ↔ List<BodyPart>?
Children parts, if present
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ int?
A number giving the size of the body in octets. Note that this size is the size in its transfer encoding and not the resulting size after any decoding.
getter/setter pair

Methods

addPart([BodyPart? childPart]) → BodyPart
collectContentInfo(ContentDisposition disposition, List<ContentInfo> result, {bool? reverse, bool? withCleanParts, bool? complete}) → void
Adds the matching disposition header with the specified disposition of this part and this children parts to the result. Optionally set reverse to true to add all parts that do not match the specified disposition. All fetchId parsed from the BODYSTRUCTURE are returned in a form compatible with the body parts tree unless withCleanParts is false. Set complete to false to skip the included rfc822 messages parts.
findFirst(MediaSubtype subtype) → BodyPart?
findFirstWithContentId(String partCid) → BodyPart?
getChildPart(String partFetchId) → BodyPart?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
write(StringBuffer buffer, [String padding = '']) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int index) → BodyPart
Eases access to a nested part, same as accessing parts[index]