ContentDispositionHeader class

Specifies the content disposition header of a mime part. Compare https://tools.ietf.org/html/rfc2183 for details.

Inheritance

Constructors

ContentDispositionHeader(String rawValue)

Properties

creationDate ↔ DateTime?
getter/setter pair
disposition ↔ ContentDisposition
getter/setter pair
dispositionText ↔ String
getter/setter pair
filename ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
modificationDate ↔ DateTime?
getter/setter pair
parameters → Map<String, String>
Any parameters, for example charset, boundary, filename, etc
finalinherited
rawValue ↔ String
The raw value of the header
getter/setter pairinherited
readDate ↔ DateTime?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ int?
getter/setter pair
value ↔ String
The value without parameters as specified in the header, eg 'text/plain' for a Content-Type header.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeQuotes(String value) → String
inherited
render([StringBuffer? buffer]) → String
renderDateField(String name, DateTime? date, StringBuffer buffer) → void
inherited
renderField(String name, String? value, bool quote, StringBuffer buffer) → void
inherited
renderRemainingFields(StringBuffer buffer, {List<String>? exclude}) → void
inherited
setParameter(String name, String quotedValue) → void
Adds a new or replaces and existing parameter name with the value quotedValue.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

attachment({String? filename, DateTime? creationDate, DateTime? modificationDate, DateTime? readDate, int? size}) → ContentDispositionHeader
Convenuience method to create a Content-Disposition: attachment header
from(ContentDisposition disposition, {String? filename, DateTime? creationDate, DateTime? modificationDate, DateTime? readDate, int? size}) → ContentDispositionHeader
inline({String? filename, DateTime? creationDate, DateTime? modificationDate, DateTime? readDate, int? size}) → ContentDispositionHeader
Convenuience method to create a Content-Disposition: inline header