Envelope class

Constructors

Envelope()

Properties

bcc ↔ List<MailAddress>?
getter/setter pair
cc ↔ List<MailAddress>?
getter/setter pair
date ↔ DateTime?
getter/setter pair
from ↔ List<MailAddress>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inReplyTo ↔ String?
getter/setter pair
messageId ↔ String?
getter/setter pair
replyTo ↔ List<MailAddress>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender ↔ MailAddress?
getter/setter pair
subject ↔ String?
getter/setter pair
to ↔ List<MailAddress>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited