body property
The body structure of the message.
This field is only populated when fetching either BODY, BODYSTRUCTURE elements.
Implementation
BodyPart? body;
The body structure of the message.
This field is only populated when fetching either BODY, BODYSTRUCTURE elements.
BodyPart? body;