MimeThread class

Abstract a mime message thread

Compare MailClient.fetchThreadedMessages for fetching message threads.

Constructors

MimeThread(MessageSequence sequence, List<MimeMessage> messages)
Creates a new thread from the given sequence with the prefetched messages.

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasMoreMessages → bool
Checks if this thread contains more messages than are already fetched
no setter
ids → List<int>
The IDs of the message sequence
final
latest → MimeMessage
The latest message in this thread
no setter
length → int
The length of this thread
no setter
messages → List<MimeMessage>
The fetched messages of this thread
final
missingMessageSequence → MessageSequence
Retrieves the sequence for any messages that have not yet been loaded.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequence → MessageSequence
The full sequence for this thread
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited