SmtpResponse class

Constructors

SmtpResponse(List<String> responseTexts)

Properties

code → int?
no setter
errorMessage → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
isFailedStatus → bool
no setter
isOkStatus → bool
no setter
message → String?
no setter
responseLines ↔ List<SmtpResponseLine>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → SmtpResponseType
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited