SmtpResponseLine class

Constructors

SmtpResponseLine(String responseText)

Properties

code ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isFailedStatus → bool
no setter
message ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → SmtpResponseType
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited